CREATE TABLE 得意先 (
       得意先ID             INTEGER NOT NULL,
       得意先コード         VARCHAR(200),
       得意先名             VARCHAR(200),
       PRIMARY KEY (得意先ID)
);


CREATE TABLE 入金 (
       入金ID               INTEGER NOT NULL,
       入金日               TIMESTAMP,
       金額                 INTEGER,
       得意先ID             INTEGER NOT NULL,
       PRIMARY KEY (入金ID), 
       FOREIGN KEY (得意先ID)
                             REFERENCES 得意先
                             ON DELETE RESTRICT
);

CREATE TABLE 売掛金残高 (
       売掛金残高ID         INTEGER NOT NULL,
       最終更新日           TIMESTAMP,
       金額                 INTEGER,
       得意先ID             INTEGER NOT NULL,
       PRIMARY KEY (売掛金残高ID), 
       FOREIGN KEY (得意先ID)
                             REFERENCES 得意先
                             ON DELETE RESTRICT
);

CREATE TABLE 請求 (
       請求ID               INTEGER NOT NULL,
       請求No               INTEGER,
       請求日               TIMESTAMP,
       得意先ID             INTEGER NOT NULL,
       PRIMARY KEY (請求ID), 
       FOREIGN KEY (得意先ID)
                             REFERENCES 得意先
                             ON DELETE RESTRICT
);

CREATE TABLE 請求明細 (
       請求明細ID           INTEGER NOT NULL,
       金額                 INTEGER,
       請求ID               INTEGER NOT NULL,
       PRIMARY KEY (請求明細ID), 
       FOREIGN KEY (請求ID)
                             REFERENCES 請求
                             ON DELETE RESTRICT
);

CREATE TABLE 売上 (
       売上ID               INTEGER NOT NULL,
       売上日               TIMESTAMP,
       売上No               INTEGER,
       得意先ID             INTEGER NOT NULL,
       PRIMARY KEY (売上ID), 
       FOREIGN KEY (得意先ID)
                             REFERENCES 得意先
                             ON DELETE RESTRICT
);

CREATE TABLE 売上明細 (
       売上明細ID           INTEGER NOT NULL,
       売上ID               INTEGER NOT NULL,
       金額                 INTEGER,
       PRIMARY KEY (売上明細ID), 
       FOREIGN KEY (売上ID)
                             REFERENCES 売上
                             ON DELETE RESTRICT
);

CREATE TABLE 売上_請求_関連 (
       売上_請求_関連ID     INTEGER NOT NULL,
       売上明細ID           INTEGER NOT NULL,
       請求明細ID           INTEGER NOT NULL,
       PRIMARY KEY (売上_請求_関連ID), 
       FOREIGN KEY (請求明細ID)
                             REFERENCES 請求明細
                             ON DELETE RESTRICT, 
       FOREIGN KEY (売上明細ID)
                             REFERENCES 売上明細
                             ON DELETE RESTRICT
);

CREATE TABLE 出荷 (
       出荷ID               INTEGER NOT NULL,
       出荷日               TIMESTAMP,
       出荷No               INTEGER,
       得意先ID             INTEGER NOT NULL,
       PRIMARY KEY (出荷ID), 
       FOREIGN KEY (得意先ID)
                             REFERENCES 得意先
                             ON DELETE RESTRICT
);

CREATE TABLE 商品 (
       商品ID               INTEGER NOT NULL,
       商品コード           VARCHAR(200),
       商品名               VARCHAR(200),
       標準単価             INTEGER,
       PRIMARY KEY (商品ID)
);


CREATE TABLE 出荷明細 (
       出荷明細ID           INTEGER NOT NULL,
       数量                 INTEGER,
       商品ID               INTEGER NOT NULL,
       出荷ID               INTEGER NOT NULL,
       PRIMARY KEY (出荷明細ID), 
       FOREIGN KEY (出荷ID)
                             REFERENCES 出荷
                             ON DELETE RESTRICT, 
       FOREIGN KEY (商品ID)
                             REFERENCES 商品
                             ON DELETE RESTRICT
);

CREATE TABLE 納品確定 (
       納品確定ID           INTEGER NOT NULL,
       出荷明細ID           INTEGER NOT NULL,
       売上明細ID           INTEGER NOT NULL,
       PRIMARY KEY (納品確定ID), 
       FOREIGN KEY (売上明細ID)
                             REFERENCES 売上明細
                             ON DELETE RESTRICT, 
       FOREIGN KEY (出荷明細ID)
                             REFERENCES 出荷明細
                             ON DELETE RESTRICT
);

CREATE TABLE 受注 (
       受注ID               INTEGER NOT NULL,
       受注日               TIMESTAMP,
       受注No               INTEGER,
       得意先ID             INTEGER NOT NULL,
       PRIMARY KEY (受注ID), 
       FOREIGN KEY (得意先ID)
                             REFERENCES 得意先
                             ON DELETE RESTRICT
);

CREATE TABLE 見積 (
       見積ID               INTEGER NOT NULL,
       見積No               INTEGER,
       見積日               TIMESTAMP,
       有効期限             TIMESTAMP,
       得意先ID             INTEGER NOT NULL,
       値引額               INTEGER,
       消費税額             INTEGER,
       PRIMARY KEY (見積ID), 
       FOREIGN KEY (得意先ID)
                             REFERENCES 得意先
                             ON DELETE RESTRICT
);

CREATE TABLE 見積_受注_関連 (
       見積_受注_関連ID     INTEGER NOT NULL,
       見積ID               INTEGER NOT NULL,
       受注ID               INTEGER NOT NULL,
       PRIMARY KEY (見積_受注_関連ID), 
       FOREIGN KEY (受注ID)
                             REFERENCES 受注,
       FOREIGN KEY (見積ID)
                             REFERENCES 見積
);

CREATE TABLE 受注明細 (
       受注明細ID           INTEGER NOT NULL,
       数量                 INTEGER,
       単価                 INTEGER,
       金額                 INTEGER,
       受注ID               INTEGER NOT NULL,
       商品ID               INTEGER NOT NULL,
       PRIMARY KEY (受注明細ID), 
       FOREIGN KEY (商品ID)
                             REFERENCES 商品
                             ON DELETE RESTRICT, 
       FOREIGN KEY (受注ID)
                             REFERENCES 受注
                             ON DELETE RESTRICT
);

CREATE TABLE 受注_出荷_関連 (
       受注明細ID           INTEGER NOT NULL,
       出荷明細ID           INTEGER NOT NULL,
       受注_出荷_関連ID     INTEGER NOT NULL,
       PRIMARY KEY (受注_出荷_関連ID), 
       FOREIGN KEY (出荷明細ID)
                             REFERENCES 出荷明細
                             ON DELETE RESTRICT, 
       FOREIGN KEY (受注明細ID)
                             REFERENCES 受注明細
                             ON DELETE RESTRICT
);

CREATE TABLE 仕入先 (
       仕入先ID             INTEGER NOT NULL,
       仕入先名             VARCHAR(200),
       PRIMARY KEY (仕入先ID)
);


CREATE TABLE 発注 (
       発注ID               INTEGER NOT NULL,
       発注日               TIMESTAMP,
       発注No               INTEGER,
       商品ID               INTEGER NOT NULL,
       仕入先ID             INTEGER NOT NULL,
       数量                 INTEGER,
       PRIMARY KEY (発注ID), 
       FOREIGN KEY (仕入先ID)
                             REFERENCES 仕入先,
       FOREIGN KEY (商品ID)
                             REFERENCES 商品
);

CREATE TABLE 在庫 (
       在庫ID               INTEGER NOT NULL,
       最終更新日           TIMESTAMP,
       数量                 INTEGER,
       商品ID               INTEGER NOT NULL,
       PRIMARY KEY (在庫ID), 
       FOREIGN KEY (商品ID)
                             REFERENCES 商品
);


CREATE TABLE 入荷 (
       入荷ID               INTEGER NOT NULL,
       入荷日               TIMESTAMP,
       数量                 INTEGER,
       商品ID               INTEGER NOT NULL,
       PRIMARY KEY (入荷ID), 
       FOREIGN KEY (商品ID)
                             REFERENCES 商品
);


CREATE TABLE 見積明細 (
       見積明細ID           INTEGER NOT NULL,
       数量                 INTEGER,
       単価                 INTEGER,
       金額                 INTEGER,
       見積ID               INTEGER NOT NULL,
       商品ID               INTEGER NOT NULL,
       PRIMARY KEY (見積明細ID), 
       FOREIGN KEY (商品ID)
                             REFERENCES 商品,
       FOREIGN KEY (見積ID)
                             REFERENCES 見積
);